@@ -15,20 +15,22 @@ import string
 import random
 import copy
 import coloredlogs
+import shutil
+from distutils.dir_util import copy_tree
 
 from pathlib import Path
 
-FORMAT = '%(asctime)s-%(levelname)s %(message)s'
-logging.getLogger("asyncio").setLevel(logging.WARNING)
-#logging.basicConfig(format=FORMAT)
 log = logging.getLogger(name="dosk")
-coloredlogs.install(fmt=FORMAT, level='INFO')#, logger=log)
+FORMAT = '%(asctime)s-%(levelname)s-%(name)s %(message)s'
 env_cmd = ';jq -n env > {}.json'
 
 def main():
     args = parse_args()
-    logging.basicConfig(level=args.verbose)
-    tasks = TaskDefs('dosk.yml')
+    coloredlogs.install(fmt=FORMAT, level=args.verbose)
+    path = str(Path(os.getcwd()))
+    if args.local:
+        path = local_build(path)
+    tasks = TaskDefs('dosk.yml', path)
     try:
         task = tasks[args.task]
     except KeyError:
@@ -39,6 +41,15 @@ def main():
         loop.add_signal_handler(sig, handler)
     loop.run_until_complete(task.run())
 
+def local_build(path):
+    # copy directory for local build
+    os.mkdir(str(path) + '/local') 
+    fromDirectory = str(path)
+    path = str(path) + '/local'
+    copy_tree(fromDirectory, path)
+    shutil.rmtree(path + '/local')
+
+    return path
 
 def parse_args():
     parser = argparse.ArgumentParser(prog ='dock', description ='Do Task - The Simple DevOps Task Runner') 
@@ -51,10 +62,10 @@ def parse_args():
                         help ="Load local variables") 
 
     verbose = parser.add_mutually_exclusive_group()
-    verbose.add_argument('--verbose', '-v',  action="store_const", const=logging.DEBUG, default=logging.INFO,
+    verbose.add_argument('--verbose', '-v',  action="store_const", const='DEBUG', default='INFO',
                         help="Print additional information")
 
-    verbose.add_argument('--quiet', '-q', action="store_const", dest="verbose", const=logging.WARNING,
+    verbose.add_argument('--quiet', '-q', action="store_const", dest="verbose", const='WARNING',
                         help="Print less information")
 
     args = parser.parse_args()
@@ -191,8 +202,9 @@ def inplace_change(filename, old_string, new_string):
     writing_file.close()
 
 class TaskDefs(dict):
-    def __init__(self, taskfile):
+    def __init__(self, taskfile, path):
         self.taskfile = Path(taskfile)
+        self.path = path
         with open(taskfile) as config:
             yaml = YAML()
             parsed = yaml.load(config)
@@ -216,7 +228,7 @@ class TaskDefs(dict):
             path = Path(os.getcwd())
             self.run_vars = {}
 
-            directory = str(path)
+            directory = self.path
             if 'dir' in obj:
                 post = obj['dir']
                 directory = directory + '/' + post.replace('$', '')
@@ -308,8 +320,6 @@ class Task(object):
         await self.proc.wait()
         await load_env(rando)
 
-
-
 class PythonTask(object):
     def __init__(self, program):
         logging.debug('Creating task with command "{}"'.format(program))
@@ -352,8 +362,8 @@ class TaskList(object):
             if isinstance(self.loop, int):
                 self.wloop = 'count < ' + str(self.loop)
             else:
-                self.vars['looplist'] = self.loop
-                length = len(self.loop)
+                self.vars['looplist'] = self.vars[self.loop]
+                length = len(self.vars['looplist'])
                 self.wloop = 'count < ' + str(length)
         else:
             self.wloop   = 'count < 1'
@@ -400,7 +410,7 @@ class SequentialTaskList(TaskList):
                 self.vars['count'] =  count
                 
                 if 'looplist' in self.vars:
-                    self.vars['loop'] = self.vars['looplist'][count]
+                    self.vars['loop'] = self.vars['looplist'][count - 1]
 
                 for i, task in enumerate(self.tasks):
                     run_task = copy.copy(task)
@@ -436,22 +446,53 @@ class SequentialTaskList(TaskList):
 
 class AsyncTaskList(TaskList):
     async def run(self, args=None):
-        runtasks = list
-        count = 0
         if args:
             error("Additional arguments not valid for Async tasks")
+
+        run_tasks = copy.copy(self.tasks)
+        print(run_tasks)
+        count = 0
+        env = os.environ.copy()
+        self.vars.update(env)
+
+        if self.condition == False:
+            condition = await env_ject(self.vars['condition'])
+            if eval(condition , self.vars):
+                self.condition = True
+
+        if 'replace' in self.vars:
+            os.chdir(self.vars['dir'])
+            if isinstance(self.vars['replace'], list):
+                for line in self.vars['replace']:
+                    old = await env_ject(line[1])
+                    new = await env_ject(line[2])
+                    await _inplace_change(line[0], old.format(**self.vars), new.format(**self.vars))
+
         while eval(self.wloop):
             count += 1 
             for i, task in enumerate(self.tasks):
                 task.update(self.vars)
+                run_tasks.append(task)
                 
         # Loop Time
-#        os.chdir(self.vars['dir'])
         await asyncio.wait(
-            [task.run() for task in self.tasks],
+            [task.run() for task in run_tasks],
             return_when=asyncio.FIRST_EXCEPTION,
         )
 
+        if 'inject' in self.vars:
+            if isinstance(self.vars['inject'], list):
+                for line in self.vars['inject']:
+                    old = await env_ject(line[1])
+                    new = await env_ject(line[2])
+                    await _inplace_change(line[0], old.format(**self.vars), new.format(**self.vars))
+
+        if 'append' in self.vars:
+            if isinstance(self.vars['append'], list):
+                for line in self.vars['append']:
+                    clean = await env_string(line[1])
+                    await _append_line(line[0], clean.format(**self.vars))
+
     def terminate(self):
         for task in self.tasks:
             task.terminate()
